@@ -926,7 +926,7 @@ groups['-읍시다'] = [
 #### 연결: -자
 groups['-자'] = [
     { 'rules': [[u'-자', '', '']],
-      'after': ['#동사'], # TODO: 일부 형용사
+      'after': ['#용언', '#이다', '-으시-', '-었-'], # TODO: 일부 형용사
     },
 ]
 
@@ -1376,6 +1376,13 @@ groups['-다는'] = [
     },
 ]
 
+#### 종결: -대 (다고 해)
+groups['-대'] = [
+    { 'rules': [[u'-대', '', '']],
+      'after': ['#용언', '-으시-', '-었-', '-겠-'],
+    },
+]
+
 #### 연결: -대도 (다고 하여도)
 groups['-대도'] = [
     { 'rules': [[u'-대도', '', '']],
@@ -1383,6 +1390,13 @@ groups['-대도'] = [
     },
 ]
 
+#### 연결: -대서 (다고 하여서)
+groups['-대서'] = [
+    { 'rules': [[u'-대서', '', '']],
+      'after': ['#형용사', '-으시-', '-었-', '-겠-'],
+    },
+]
+
 #### 연결: -더라도
 groups['-더라도'] = [
     { 'rules': [[u'-더라도', '', '']],
@@ -1674,13 +1688,6 @@ groups['-으오'] = [
     HIEUH_IRREGULAR_TYPICAL_CLASS(u'-오', ['#용언']),
 ]
 
-#### 연결: -대서 (다고 하여서)
-groups['-대서'] = [
-    { 'rules': [[u'-대서', '', '']],
-      'after': ['#형용사', '-으시-', '-었-', '-겠-'],
-    },
-]
-
 #### 종결: -잖아 (~지 않아)
 groups['-잖아'] = [
     { 'rules': [[u'-잖아', '', '']],
@@ -1988,6 +1995,7 @@ groups['-으마'] = [
                 [u'-마', T_RIEUL, T_RIEUL],
                 [u'-으마', COND_T_NOT_RIEUL, '']],
       'after': ['#동사'],
+      'notcond': ['#준말용언'],
     },
 ]
 
@@ -1998,3 +2006,67 @@ groups['-던지'] = [
     },
 ]
 
+#### 종결: -더구나
+
+groups['-더구나'] = [
+    { 'rules': [[u'-더구나', '', '']],
+      'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-'],
+    },
+]
+
+#### 종결: -라면서,-으라면서
+
+groups['-라면서'] = [
+    { 'rules': [[u'-라면서', COND_V_ALL, ''],
+                [u'-라면서', T_RIEUL, T_RIEUL],
+                [u'-으라면서', COND_T_NOT_RIEUL, ''],
+                # 준말
+                [u'-라며', COND_V_ALL, ''],
+                [u'-라며', T_RIEUL, T_RIEUL],
+                [u'-으라며', COND_T_NOT_RIEUL, '']],
+      'after': ['#이다', '아니다', '#동사', '-으시-', '-었-', '-더-', '-으리-'],
+      'notcond': ['#준말용언'],
+    },
+]
+
+#### 종결: -던가
+
+groups['-던가'] = [
+    { 'rules': [[u'-던가', '', '']],
+      'after': ['#용언'],
+    },
+]
+
+#### 연결: -다느니
+
+groups['-다느니'] = [
+    { 'rules': [[u'-다느니', '', '']],
+      'after': ['#형용사', '-으시-', '-었-', '-겠-'],
+    },
+]
+
+#### 연결: -는다느니,-ㄴ다느니
+
+groups['-는다느니'] = [
+    { 'rules': [[u'-%s다느니' % T_NIEUN, COND_V_ALL, ''],
+                [u'-%s다느니' % T_NIEUN, T_RIEUL, T_RIEUL],
+                [u'-는다느니', COND_T_NOT_RIEUL, '']],
+      'after': ['#동사', '-으시-'],
+    },
+]
+
+#### 연결: -다가는
+
+groups['-다가는'] = [
+    { 'rules': [[u'-다가는', '', '']],
+      'after': ['#이다', '#용언', '-으시-', '-었-', '-겠-'],
+    },
+]
+
+#### 연결: -다기보다는 (-다고 하기보다는)
+
+groups['-다기보다는'] = [
+    { 'rules': [[u'-다기보다는', '', '']],
+      'after': ['#이다', '#용언', '-으시-', '-었-', '-겠-'],
+    },
+]
